@@ -2,6 +2,7 @@
     Copyright (C) 2000 Matej Koss <koss@miesto.sk>
     Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
     Copyright (C) 2007 Rafael Fernández López <ereslibre@kde.org>
+    Copyright (C) 2009 Shaun Reich <shaun.reich@kdemail.net>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -25,7 +26,6 @@
 #include <QProcess>
 #include <QTimer>
 #include <QLabel>
-#include <QCheckBox>
 #include <QProgressBar>
 #include <QVBoxLayout>
 #include <QGridLayout>
@@ -42,8 +42,9 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kwindowsystem.h>
+#include <kseparator.h>
 
-void KWidgetJobTracker::Private::_k_slotShowProgressWidget()
+void KWidgetJobTracker::Private::_k_showProgressWidget()
 {
     if (progressWidgetsToBeShown.isEmpty()) {
         return;
@@ -77,21 +78,22 @@ QWidget *KWidgetJobTracker::widget(KJob *job)
 
 void KWidgetJobTracker::registerJob(KJob *job)
 {
-    KAbstractWidgetJobTracker::registerJob(job);
-
     Private::ProgressWidget *vi = new Private::ProgressWidget(job, this, d->parent);
     vi->jobRegistered = true;
     vi->setAttribute(Qt::WA_DeleteOnClose);
     d->progressWidget.insert(job, vi);
     d->progressWidgetsToBeShown.enqueue(job);
 
-    QTimer::singleShot(500, this, SLOT(_k_slotShowProgressWidget()));
+    KAbstractWidgetJobTracker::registerJob(job);
+
+    QTimer::singleShot(500, this, SLOT(_k_showProgressWidget()));
 }
 
 void KWidgetJobTracker::unregisterJob(KJob *job)
 {
     KAbstractWidgetJobTracker::unregisterJob(job);
 
+    d->progressWidgetsToBeShown.removeAll(job);
     KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, 0);
     if (!pWidget) {
         return;
@@ -108,7 +110,7 @@ bool KWidgetJobTracker::keepOpen(KJob *job) const
         return false;
     }
 
-    return pWidget->keepOpen();
+    return pWidget->keepOpenCheck->isChecked();
 }
 
 void KWidgetJobTracker::infoMessage(KJob *job, const QString &plain, const QString &rich)
@@ -203,24 +205,19 @@ void KWidgetJobTracker::resumed(KJob *job)
     pWidget->resumed();
 }
 
-bool KWidgetJobTracker::Private::ProgressWidget::keepOpen() const
-{
-    return keepOpenChecked;
-}
-
 void KWidgetJobTracker::Private::ProgressWidget::ref()
 {
-    refCount++;
+    ++refCount;
 }
 
 void KWidgetJobTracker::Private::ProgressWidget::deref()
 {
     if (refCount) {
-        refCount--;
+        --refCount;
     }
 
     if (!refCount) {
-        if (!keepOpenChecked) {
+        if (!keepOpenCheck->isChecked()) {
             closeNow();
         } else {
             slotClean();
@@ -274,7 +271,7 @@ void KWidgetJobTracker::Private::ProgressWidget::description(const QString &titl
     setWindowTitle(title);
     caption = title;
 
-    sourceInvite->setText(field1.first);
+    sourceInvite->setText(i18nc("%1 is the label, we add a ':' to it", "%1:", field1.first));
     sourceEdit->setText(field1.second);
 
     if (field2.first.isEmpty()) {
@@ -282,7 +279,7 @@ void KWidgetJobTracker::Private::ProgressWidget::description(const QString &titl
     } else {
         setDestVisible(true);
         checkDestination(KUrl(field2.second));
-        destInvite->setText(field2.first);
+        destInvite->setText(i18nc("%1 is the label, we add a ':' to it", "%1:", field2.first));
         destEdit->setText(field2.second);
     }
 }
@@ -423,13 +420,13 @@ void KWidgetJobTracker::Private::ProgressWidget::slotClean()
 
 void KWidgetJobTracker::Private::ProgressWidget::suspended()
 {
-    pauseButton->setText(i18n("Resume"));
+    pauseButton->setText(i18n("&Resume"));
     suspendedProperty = true;
 }
 
 void KWidgetJobTracker::Private::ProgressWidget::resumed()
 {
-    pauseButton->setText(i18n("Pause"));
+    pauseButton->setText(i18n("&Pause"));
     suspendedProperty = false;
 }
 
@@ -450,13 +447,10 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
                              KIconLoader::global()->loadIcon( "document-save", KIconLoader::NoGroup, 16 ) );
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(KDialog::marginHint());
-    topLayout->setSpacing(KDialog::spacingHint() );
-    topLayout->addStrut( 360 );   // makes dlg at least that wide
 
     QGridLayout *grid = new QGridLayout();
     topLayout->addLayout(grid);
-    grid->addItem(new QSpacerItem(KDialog::spacingHint(),0),0,1); //addColSpacing(1, KDialog::spacingHint());
+    grid->addItem(new QSpacerItem(KDialog::spacingHint(),0),0,1);
     // filenames or action name
     sourceInvite = new QLabel(i18nc("The source url of a job", "Source:"), this);
     grid->addWidget(sourceInvite, 0, 0);
@@ -482,41 +476,50 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     progressHBox->addWidget(progressBar);
 
     suspendedProperty = false;
-    pauseButton = new KPushButton(i18n("Pause"), this);
-    QObject::connect(pauseButton, SIGNAL(clicked()),
-                     this, SLOT(_k_pauseResumeClicked()));
-    progressHBox->addWidget(pauseButton);
 
     // processed info
     QHBoxLayout *hBox = new QHBoxLayout();
     topLayout->addLayout(hBox);
 
+    arrowButton = new KPushButton(this);
+    arrowButton->setMaximumSize(QSize(32,25));
+    arrowButton->setIcon(KIcon("arrow-down"));
+    arrowButton->setToolTip(i18n("Click this to expand the dialog, to show details"));
+    arrowState = Qt::DownArrow;
+    connect(arrowButton, SIGNAL(clicked()), this, SLOT(_k_arrowToggled()));
+    hBox->addWidget(arrowButton);
+    hBox->addStretch(1);
+
+    KSeparator *separator1 = new KSeparator(Qt::Horizontal, this);
+    topLayout->addWidget(separator1);
+
     sizeLabel = new QLabel(this);
-    hBox->addWidget(sizeLabel);
+    hBox->addWidget(sizeLabel, 0, Qt::AlignLeft);
 
     resumeLabel = new QLabel(this);
     hBox->addWidget(resumeLabel);
 
-    progressLabel = new QLabel(this);
-/*    progressLabel->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                                            QSizePolicy::Preferred));*/
-    progressLabel->setAlignment(Qt::AlignRight);
-    hBox->addWidget(progressLabel);
+    pauseButton = new KPushButton(i18n("&Pause"), this);
+    connect(pauseButton, SIGNAL(clicked()), this, SLOT(_k_pauseResumeClicked()));
+    hBox->addWidget(pauseButton);
 
     hBox = new QHBoxLayout();
     topLayout->addLayout(hBox);
 
     speedLabel = new QLabel(this);
     hBox->addWidget(speedLabel, 1);
+    speedLabel->hide();
 
-    QFrame *line = new QFrame(this);
-    line->setFrameShape(QFrame::HLine);
-    line->setFrameShadow(QFrame::Sunken);
-    topLayout->addWidget(line);
+    hBox = new QHBoxLayout();
+    topLayout->addLayout(hBox);
+
+    progressLabel = new QLabel(this);
+    progressLabel->setAlignment(Qt::AlignLeft);
+    hBox->addWidget(progressLabel);
+    progressLabel->hide();
 
     keepOpenCheck = new QCheckBox(i18n("&Keep this window open after transfer is complete"), this);
-    QObject::connect(keepOpenCheck, SIGNAL(toggled(bool)),
-                     this, SLOT(_k_keepOpenToggled(bool)));
+    connect(keepOpenCheck, SIGNAL(toggled(bool)), this, SLOT(_k_keepOpenToggled(bool)));
     topLayout->addWidget(keepOpenCheck);
     keepOpenCheck->hide();
 
@@ -524,29 +527,25 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     topLayout->addLayout(hBox);
 
     openFile = new KPushButton(i18n("Open &File"), this);
-    QObject::connect(openFile, SIGNAL(clicked()),
-                     this, SLOT(_k_openFile()));
+    connect(openFile, SIGNAL(clicked()), this, SLOT(_k_openFile()));
     hBox->addWidget(openFile);
     openFile->setEnabled(false);
     openFile->hide();
 
     openLocation = new KPushButton(i18n("Open &Destination"), this);
-    QObject::connect(openLocation, SIGNAL(clicked()),
-                     this, SLOT(_k_openLocation()));
+    connect(openLocation, SIGNAL(clicked()), this, SLOT(_k_openLocation()));
     hBox->addWidget(openLocation);
     openLocation->hide();
 
     hBox->addStretch(1);
 
     cancelClose = new KPushButton(KStandardGuiItem::cancel(), this);
-    QObject::connect(cancelClose, SIGNAL(clicked()),
-                     this, SLOT(_k_stop()));
+    connect(cancelClose, SIGNAL(clicked()), this, SLOT(_k_stop()));
     hBox->addWidget(cancelClose);
 
     resize(sizeHint());
     setMaximumHeight(sizeHint().height());
 
-    keepOpenChecked = false;
     setWindowTitle(i18n("Progress Dialog")); // show something better than kuiserver
 }
 
@@ -582,6 +581,7 @@ void KWidgetJobTracker::Private::ProgressWidget::setDestVisible(bool visible)
         destInvite->setText( QString() );
         destEdit->setText( QString() );
     }
+    setMaximumHeight(sizeHint().height());
 }
 
 void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const KUrl &dest)
@@ -589,7 +589,7 @@ void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const KUrl &de
     bool ok = true;
 
     if (dest.isLocalFile()) {
-        QString path = dest.path( KUrl::RemoveTrailingSlash );
+        QString path = dest.toLocalFile( KUrl::RemoveTrailingSlash );
         const QStringList tmpDirs = KGlobal::dirs()->resourceDirs( "tmp" );
         for (QStringList::ConstIterator it = tmpDirs.begin() ; ok && it != tmpDirs.end() ; ++it)
             if (path.contains(*it))
@@ -600,6 +600,7 @@ void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const KUrl &de
         openFile->show();
         openLocation->show();
         keepOpenCheck->show();
+        setMaximumHeight(sizeHint().height());
         location=dest;
     }
 }
@@ -611,8 +612,6 @@ void KWidgetJobTracker::Private::ProgressWidget::_k_keepOpenToggled(bool keepOpe
     } else {
         KGlobal::deref();
     }
-
-    keepOpenChecked = keepOpen;
 }
 
 void KWidgetJobTracker::Private::ProgressWidget::_k_openFile()
@@ -644,5 +643,25 @@ void KWidgetJobTracker::Private::ProgressWidget::_k_stop()
     closeNow();
 }
 
+void KWidgetJobTracker::Private::ProgressWidget::_k_arrowToggled()
+{
+    if (arrowState == Qt::DownArrow) {
+        //The arrow is in the down position, dialog is collapsed, expand it and change icon.
+        progressLabel->show();
+        speedLabel->show();
+        arrowButton->setIcon(KIcon("arrow-up"));
+        arrowButton->setToolTip(i18n("Click this to collapse the dialog, to hide details"));
+        arrowState = Qt::UpArrow;
+    } else {
+        //Collapse the dialog
+        progressLabel->hide();
+        speedLabel->hide();
+        arrowButton->setIcon(KIcon("arrow-down"));
+        arrowButton->setToolTip(i18n("Click this to expand the dialog, to show details"));
+        arrowState = Qt::DownArrow;
+    }
+    setMaximumHeight(sizeHint().height());
+}
+
 #include "kwidgetjobtracker.moc"
 #include "kwidgetjobtracker_p.moc"
