@@ -596,13 +596,13 @@ public:
 
 struct BorderRadii
 {
-    int horizontal;
-    int vertical;
+    Length horizontal;
+    Length vertical;
 
-    BorderRadii(): horizontal(0), vertical(0) {}
+    BorderRadii(): horizontal(Length(0, Fixed)), vertical(Length(0, Fixed)) {}
 
     bool hasBorderRadius() const {
-        return horizontal > 0 && vertical > 0;
+        return (!horizontal.isZero() && !vertical.isZero());
     }
 
     bool operator==(const BorderRadii& o) const;
@@ -614,7 +614,7 @@ struct BorderRadii
 class BorderRadiusData : public Shared<BorderRadiusData>
 {
 public:
-    BorderRadiusData() : Shared<BorderRadiusData>() {};
+    BorderRadiusData();
     BorderRadiusData(const BorderRadiusData &other) : Shared<BorderRadiusData>(),
         topRight(other.topRight),
         bottomRight(other.bottomRight),
@@ -1481,6 +1481,7 @@ public:
     static CachedImage* initialBackgroundImage() { return 0; }
     static CachedImage* initialListStyleImage() { return 0; }
     static unsigned short initialBorderWidth() { return 3; }
+    static BorderRadii initialBorderRadius() { return BorderRadii(); }
     static int initialLetterWordSpacing() { return 0; }
     static Length initialSize() { return Length(); }
     static Length initialMinSize() { return Length(0, Fixed); }
